//
//  JCMessageVC.m
//  JCMessageQQ
//
//  Created by QB on 16/5/9.
//  Copyright © 2016年 JC. All rights reserved.
//

#import "JCMessageVC.h"

#import "JCMessageFrameModel.h"
#import "JCMessageModel.h"
#import "JCMessageCell.h"



@interface JCMessageVC ()<UITableViewDataSource,UITableViewDelegate,UITextFieldDelegate>


@property (weak, nonatomic) IBOutlet UITableView *tableView;

@property (nonatomic, strong) NSMutableArray *messagrarrayList;

@end



@implementation JCMessageVC

//懒加载
- (NSMutableArray *)messagrarrayList {
    if (!_messagrarrayList) {
        NSString *paths = [[NSBundle mainBundle] pathForResource:@"messages.plist" ofType:nil];
        NSArray *array = [NSArray arrayWithContentsOfFile:paths];
        
        NSMutableArray *messageArray = [NSMutableArray arrayWithCapacity:array.count];
        JCMessageModel *lastMessage;
        for (NSDictionary *tempDic in array) {
            JCMessageModel *model = [JCMessageModel jcMessageModelWithNSDictionary:tempDic];
            if ([model.time isEqualToString:lastMessage.time]) {
                model.hiddenTime = YES;
            }
            JCMessageFrameModel *frameModel = [[JCMessageFrameModel alloc] init];
            frameModel.model = model;
            
            [messageArray addObject:frameModel];
        }
        
        self.messagrarrayList = messageArray;
    }
    
    return _messagrarrayList;
}


- (void)viewDidLoad {
    [super viewDidLoad];
    [self greatTableView];
    //添加通知
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(keyboardWillChangeFrame:) name:UIKeyboardWillChangeFrameNotification object:nil];
    
    
}


- (void)greatTableView {
    self.tableView.dataSource = self;
    self.tableView.delegate = self;
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    self.tableView.allowsSelection = NO;
    self.tableView.backgroundColor = [UIColor colorWithRed:240/255.0 green:240/255.0 blue:240/255.0 alpha:1];
}

///改变frame
- (void)keyboardWillChangeFrame:(NSNotification *)notification {
    //键盘弹出的时间
    CGFloat duration = [notification.userInfo[@"UIKeyboardAnimationDurationUserInfoKey"] floatValue];
    NSLog(@"-----%f",duration);
    //获取键盘的高度
    CGRect frame = [notification.userInfo[@"UIKeyboardFrameEndUserInfoKey"] CGRectValue];
    
    NSLog(@"++++%@",NSStringFromCGRect(frame));
    
    CGFloat offsetY = frame.origin.y - self.view.frame.size.height;
    
    NSLog(@"^^^^%lf",offsetY);
    //第一个参数：键盘弹出时间 第二个参数：view的偏移量
    [UIView animateWithDuration:duration animations:^{
        self.view.transform = CGAffineTransformMakeTranslation(0, offsetY);
    }];
}


#pragma mark-----UITableViewDataSource,UITableViewDelegate 代理方法

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    
    return self.messagrarrayList.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    JCMessageCell *cell = [JCMessageCell cellWithTableView:tableView];
    cell.frameMOdel = self.messagrarrayList[indexPath.row];
    return cell;
}


- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    return [self.messagrarrayList[indexPath.row] rowHeight];
}



- (void)scrollViewWillBeginDragging:(UIScrollView *)scrollView {
    //结束编辑
    [self.view endEditing:YES];
}


//隐藏导航条
- (BOOL)prefersStatusBarHidden {
    return YES;
}


#pragma mark------textField 的代理方法

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    //[self.view endEditing:YES];
    NSString *message = textField.text;
    //自己发信息
    [self sendMessage:message type:JCMessageModelTypeSelf];
    
    if ([message isEqualToString:@"你好"]) {
        
        [self sendMessage:@"你好，干啥" type:JCMessageModelTypeOther];
         textField.text = nil;
        return YES;
    } else if ([message isEqualToString:@"在做什么"]) {
        [self sendMessage:@"无聊中。。。。" type:JCMessageModelTypeOther];
         textField.text = nil;
        return YES;
    }
    
    [self sendMessage:@"工作中勿扰" type:JCMessageModelTypeOther];
    textField.text = nil;
    return YES;
}



- (void)sendMessage:(NSString *)message type:(JCMessageModelType)type {
    //创建模型
    JCMessageModel *model = [[JCMessageModel alloc] init];
    model.type = type;
    model.text = message;
    //获取时间
    NSDate *date = [NSDate date];
    //格式转化
    NSDateFormatter *matter = [[NSDateFormatter alloc] init];
    matter.dateFormat = @"HH:mm";
    model.time = [matter stringFromDate:date];
    //上一个消息
    JCMessageModel *lastMessage = [[self.messagrarrayList lastObject] model];
    
    if ([model.time isEqualToString:lastMessage.time]) {
        model.hiddenTime = YES;
    }
    JCMessageFrameModel *frameModel = [[JCMessageFrameModel alloc] init];
    frameModel.model = model;
    [self.messagrarrayList addObject:frameModel];
    [self.tableView reloadData];
    
    NSIndexPath *path = [NSIndexPath indexPathForRow:self.messagrarrayList.count - 1 inSection:0];
    [self.tableView scrollToRowAtIndexPath:path atScrollPosition:UITableViewScrollPositionBottom animated:YES];
}

@end
