//
//  JCMessageCell.m
//  JCMessageQQ
//
//  Created by QB on 16/5/9.
//  Copyright © 2016年 JC. All rights reserved.
//

#import "JCMessageCell.h"

#import "JCMessageModel.h"

#import "UIImage+JCImage.h"

@interface JCMessageCell ()
///时间
@property (nonatomic, weak) UILabel *timeLabel;
///信息
@property (nonatomic, weak) UIButton *messageBtn;
///头像
@property (nonatomic, weak) UIImageView *iconView;


@end


@implementation JCMessageCell

+ (instancetype)cellWithTableView:(UITableView *)tableView {
    
    static NSString *identifier = @"cell";
    
    JCMessageCell *cell = [tableView dequeueReusableCellWithIdentifier:identifier];
    
    if (cell == nil) {
        cell = [[JCMessageCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:identifier];
    }
    
    return cell;
}

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier {
    
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        
        [self setupChildView];
        
    }
    
    return self;
}


///布局子控件
- (void)setupChildView {
    //清除cell的颜色
    self.backgroundColor = [UIColor clearColor];
    //时间
    UILabel *timeLabel = [[UILabel alloc] init];
    timeLabel.textAlignment = NSTextAlignmentCenter;
    [self.contentView addSubview:timeLabel];
    self.timeLabel = timeLabel;
    //信息
    UIButton *messageBtn = [[UIButton alloc] init];
    messageBtn.titleLabel.font = [UIFont systemFontOfSize:14.0];
    messageBtn.titleLabel.numberOfLines = 0;
    [messageBtn setTitleColor:[UIColor blackColor] forState:0];
    //设置内边距
    messageBtn.contentEdgeInsets = UIEdgeInsetsMake(20, 20, 20, 20);
    [self.contentView addSubview:messageBtn];
    self.messageBtn = messageBtn;
    //头像
    UIImageView *iconView = [[UIImageView alloc] init];
    //设置圆形
    iconView.layer.cornerRadius = 30;
    iconView.layer.masksToBounds = YES;
    [self.contentView addSubview:iconView];
    self.iconView = iconView;
    self.iconView.backgroundColor = [UIColor greenColor];
}





- (void)setFrameMOdel:(JCMessageFrameModel *)frameMOdel {
    _frameMOdel = frameMOdel;
    //时间
    self.timeLabel.text = frameMOdel.model.time;
    self.timeLabel.frame = frameMOdel.timeFrame;
    //头像
    if (frameMOdel.model.type == JCMessageModelTypeSelf) {
        self.iconView.image = [UIImage imageNamed:@"me"];
    } else {
        self.iconView.image = [UIImage imageNamed:@"other"];
        self.iconView.backgroundColor = [UIColor greenColor];
    }
    
    self.iconView.frame = frameMOdel.iconFrame;
    
    //消息
     [self.messageBtn setTitle:frameMOdel.model.text forState:0];
    self.messageBtn.frame = frameMOdel.messageBtnFrame;
    //设置背景图片
    if (frameMOdel.model.type == JCMessageModelTypeSelf) {
        [self.messageBtn setBackgroundImage:[UIImage resizeImage:@"chat_send_nor"] forState:0];
        [self.messageBtn setBackgroundImage:[UIImage resizeImage:@"chat_send_press_pic"] forState:UIControlStateHighlighted];
    } else {
        [self.messageBtn setBackgroundImage:[UIImage resizeImage:@"chat_recive_nor"] forState:0];
        [self.messageBtn setBackgroundImage:[UIImage resizeImage:@"chat_recive_press_pic"] forState:UIControlStateHighlighted];
    }
}



@end
